@@ -3,7 +3,7 @@ package Net::GitHub::V3;
 use Moo;
 use Types::Standard qw(InstanceOf);
 
-our $VERSION = '0.69';
+our $VERSION = '0.94';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 with 'Net::GitHub::V3::Query';
@@ -17,6 +17,7 @@ use Net::GitHub::V3::GitData;
 use Net::GitHub::V3::Gists;
 use Net::GitHub::V3::OAuth;
 use Net::GitHub::V3::Events;
+use Net::GitHub::V3::Gitignore;
 use Net::GitHub::V3::Search;
 
 has '+is_main_module' => (default => 1);
@@ -125,6 +126,16 @@ has 'search' => (
     },
 );
 
+has 'gitignore' => (
+    is => 'rw',
+    isa => InstanceOf['Net::GitHub::V3::Gitignore'],
+    lazy => 1,
+    default => sub {
+        my $self = shift;
+        return Net::GitHub::V3::Gitignore->new( $self->args_to_pass );
+    },
+);
+
 no Moo;
 
 1;
@@ -211,7 +222,7 @@ from the API. By switching B<RaiseError> on you can make the be turned into
 exceptions instead, so that you don't have to check for error response after
 every call.
 
-=head3 next_url, last_url, prev_url, first_url, per_page
+=head3 Iterating over pages: next_url, last_url, prev_url, first_url, per_page
 
 Any methods which return multiple results I<may> be paginated. After performing
 a query you should check to see if there are more results. These attributes will
@@ -220,7 +231,7 @@ be reset for each query.
 The predicates to check these attributes are C<has_next_page>, C<has_last_page>,
 C<has_prev_page> and C<has_first_page>.
 
-C<per_page> is default to 100. it will be applied to GET urls no matter it supports or not.
+C<per_page> defaults to 100. It will be applied to GET urls no matter it supports or not.
 
 See Github's documentation: L<http://developer.github.com/v3/#pagination>
 
@@ -231,6 +242,47 @@ See Github's documentation: L<http://developer.github.com/v3/#pagination>
       push @issues, $gh->issue->next_page;
   }
 
+
+=head3 Iterating over individual items: next_xxx and close_xxx
+
+The queries which can return paginated results can also be evaluated one by
+one, like this:
+
+  while (my $issue = $gh->issue->next_repos_issue( @args )) {
+    # do something with $issue
+  }
+
+The arguments to next_repos_issue are the same as for repos_issues,
+and is also applicable to all other interfaces which offer a next_xxx
+method.  All available next_xxx methods are listed in the
+documentation of the corresponding modules, see the list below.
+
+If you loop over the next_xxx interfaces, new API calls will be
+performed automatically, but only when needed to fetch more items.  An
+undefined return value means there are no more items.
+
+To start over with the first item, you need to close the iteration.
+Every next_xxx method has a corresponding close_xxx method which must
+be called with exactly the same parameters as the next_xxx method to
+take effect:
+
+  $gh->issue->close_repos_issue(@args);
+
+If you use Net::GitHub::V3 in a command line program, there is no need
+to call the close_xxx methods at all.  As soon as the Net::GitHub::V3
+object $gh goes out of scope, everything is neatly cleaned up.
+
+However, if you have a long-lived Net::GitHub::V3 object, e.g. in a
+persistent service process which provides an own interface to its
+users and talks to GitHub under the hood, then it is advisable to
+close the iterations when you're done with them.
+
+For brevity and because they usually are not needed, the close_xxx
+methods are not listed with their modules.  It is guaranteed that
+I<every> next_xxx method has a corresponding close_xxx method.
+
+
+
 =head3 ua
 
 To set the proxy for ua, you can do something like following
@@ -293,7 +345,7 @@ L<Net::GitHub::V3::Repos>
 =head3 issue
 
     my @issues = $gh->issue->issues();
-    my $issue  = $gh->issue->issue($issue_id);
+    my $issue  = $gh->issue->issue($issue_number);
 
 L<Net::GitHub::V3::Issues>
 
